package junit5; // <--also can put the test in the same package as tested code (as in pizza1) 

import calc.Calculator;
//Example JUnit5 test (note changed imports from JUnit4)
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Disabled;

public class CalculatorTest {

	private static Calculator calculator = new Calculator();
	
    // @Before -- JUnit 4
	@BeforeEach  // JUnit5
	public void clearCalculator() {
		calculator.clear();
	}

	// Note change from JUnit4: new Assertions class for assertions in JUnit5
	@Test
	public void add() {
		calculator.add(1);
		calculator.add(1);
		Assertions.assertEquals(calculator.getResult(), 2);
	}

	@Test
	public void subtract() {
		calculator.add(10);
		calculator.subtract(2);
		Assertions.assertEquals(calculator.getResult(), 8);
	}

	@Test
	public void divide() {
		calculator.add(8);
		calculator.divide(2);
		Assertions.assertEquals(calculator.getResult(), 5);
	}

	// @Test(expected = ArithmeticException.class) JUnit 4
	// JUnit5: no method annotation, but new kind of assertion instead--
	public void divideByZero() {
		Assertions.assertThrows(ArithmeticException.class, () -> {
			calculator.divide(0);
		});
	}

	// @Ignore("not ready yet") -- JUnit 4
	@Disabled   // JUnit 5
	@Test
	public void multiply() {
		calculator.add(10);
		// calculator.multiply(10);
		Assertions.assertEquals(calculator.getResult(), 100);
	}
}
